@@ -1,21 +1,22 @@
 # -*- coding=utf-8 -*-
 from __future__ import absolute_import, print_function
 
+from urllib.parse import quote
+from urllib.parse import unquote as url_unquote
+from urllib.parse import unquote_plus
+
 import attr
-import pip_shims.shims
-from orderedmultidict import omdict
-from six.moves.urllib.parse import quote_plus, unquote_plus
-from urllib3 import util as urllib3_util
+from pip._internal.models.link import Link
+from pip._internal.req.constructors import _strip_extras
 from urllib3.util import parse_url as urllib3_parse
 from urllib3.util.url import Url
 
 from ..environment import MYPY_RUNNING
+from ..utils import is_installable_file
 from .utils import extras_to_string, parse_extras
 
 if MYPY_RUNNING:
-    from typing import Dict, List, Optional, Text, Tuple, TypeVar, Union
-    from pip_shims.shims import Link
-    from vistir.compat import Path
+    from typing import Dict, Optional, Text, Tuple, TypeVar, Union
 
     _T = TypeVar("_T")
     STRING_TYPE = Union[bytes, str, Text]
@@ -24,10 +25,9 @@ if MYPY_RUNNING:
 
 def _get_parsed_url(url):
     # type: (S) -> Url
-    """
-    This is a stand-in function for `urllib3.util.parse_url`
+    """This is a stand-in function for `urllib3.util.parse_url`
 
-    The orignal function doesn't handle special characters very well, this simply splits
+    The original function doesn't handle special characters very well, this simply splits
     out the authentication section, creates the parsed url, then puts the authentication
     section back in, bypassing validation.
 
@@ -42,15 +42,14 @@ def _get_parsed_url(url):
         auth, _, url = url.rpartition("@")
         url = "{scheme}://{url}".format(scheme=scheme, url=url)
         parsed = urllib3_parse(url)._replace(auth=auth)
-    if parsed.auth and unquote_plus(parsed.auth) != parsed.auth:
-        return parsed._replace(auth=unquote_plus(parsed.auth))
+    if parsed.auth:
+        return parsed._replace(auth=url_unquote(parsed.auth))
     return parsed
 
 
 def remove_password_from_url(url):
     # type: (S) -> S
-    """
-    Given a url, remove the password and insert 4 dashes
+    """Given a url, remove the password and insert 4 dashes.
 
     :param url: The url to replace the authentication in
     :type url: S
@@ -87,8 +86,8 @@ class URI(object):
     username = attr.ib(default="", type=str)
     #: Password parsed from `user:password@hostname`
     password = attr.ib(default="", type=str, repr=False)
-    #: An orderedmultidict representing query fragments
-    query_dict = attr.ib(factory=omdict, type=omdict)
+    #: A dictionary representing query fragments
+    query_dict = attr.ib(factory=dict, type=dict)
     #: The name of the specified package in case it is a VCS URI with an egg fragment
     name = attr.ib(default="", type=str)
     #: Any extras requested from the requirement
@@ -105,18 +104,18 @@ class URI(object):
     def _parse_query(self):
         # type: () -> URI
         query = self.query if self.query is not None else ""
-        query_dict = omdict()
+        query_dict = dict()
         queries = query.split("&")
         query_items = []
         subdirectory = self.subdirectory if self.subdirectory else None
         for q in queries:
             key, _, val = q.partition("=")
-            val = unquote_plus(val.replace("+", " "))
+            val = unquote_plus(val)
             if key == "subdirectory" and not subdirectory:
                 subdirectory = val
             else:
                 query_items.append((key, val))
-        query_dict.load(query_items)
+        query_dict.update(query_items)
         return attr.evolve(
             self, query_dict=query_dict, subdirectory=subdirectory, query=query
         )
@@ -133,12 +132,12 @@ class URI(object):
         extras = self.extras
         for q in fragments:
             key, _, val = q.partition("=")
-            val = unquote_plus(val.replace("+", " "))
+            val = unquote_plus(val)
             fragment_items[key] = val
             if key == "egg":
                 from .utils import parse_extras
 
-                name, stripped_extras = pip_shims.shims._strip_extras(val)
+                name, stripped_extras = _strip_extras(val)
                 if stripped_extras:
                     extras = tuple(parse_extras(stripped_extras))
             elif key == "subdirectory":
@@ -159,10 +158,10 @@ class URI(object):
             username_is_quoted, password_is_quoted = False, False
             quoted_username, quoted_password = "", ""
             if password:
-                quoted_password = quote_plus(password)
+                quoted_password = quote(password)
                 password_is_quoted = quoted_password != password
             if username:
-                quoted_username = quote_plus(username)
+                quoted_username = quote(username)
                 username_is_quoted = quoted_username != username
             return attr.evolve(
                 self,
@@ -177,14 +176,14 @@ class URI(object):
         # type: (bool, bool) -> str
         password = self.password if self.password else ""
         if password and unquote and self._password_is_quoted:
-            password = unquote_plus(password)
+            password = url_unquote(password)
         return password
 
     def get_username(self, unquote=False):
         # type: (bool) -> str
         username = self.username if self.username else ""
         if username and unquote and self._username_is_quoted:
-            username = unquote_plus(username)
+            username = url_unquote(username)
         return username
 
     @staticmethod
@@ -264,8 +263,8 @@ class URI(object):
         strip_subdir=False,  # type: bool
     ):
         # type: (...) -> str
-        """
-        Converts the current URI to a string, unquoting or escaping the password as needed
+        """Converts the current URI to a string, unquoting or escaping the
+        password as needed.
 
         :param escape_password: Whether to replace password with ``----``, default True
         :param escape_password: bool, optional
@@ -369,9 +368,7 @@ class URI(object):
     @property
     def as_link(self):
         # type: () -> Link
-        link = pip_shims.shims.Link(
-            self.to_string(escape_password=False, strip_ssh=False, direct=False)
-        )
+        link = Link(self.to_string(escape_password=False, strip_ssh=False, direct=False))
         return link
 
     @property
@@ -452,6 +449,11 @@ class URI(object):
         # type: () -> str
         return self.to_string(escape_password=False, unquote=False)
 
+    @property
+    def is_installable(self):
+        # type: () -> bool
+        return self.is_file_url and is_installable_file(self.bare_url)
+
     @property
     def is_vcs(self):
         # type: () -> bool
@@ -474,21 +476,18 @@ def update_url_name_and_fragment(name_with_extras, ref, parsed_dict):
     if name_with_extras:
         fragment = ""  # type: Optional[str]
         parsed_extras = ()
-        name, extras = pip_shims.shims._strip_extras(name_with_extras)
+        name, extras = _strip_extras(name_with_extras)
         if extras:
             parsed_extras = parsed_extras + tuple(parse_extras(extras))
         if parsed_dict["fragment"] is not None:
             fragment = "{0}".format(parsed_dict["fragment"])
             if fragment.startswith("egg="):
                 _, _, fragment_part = fragment.partition("=")
-                fragment_name, fragment_extras = pip_shims.shims._strip_extras(
-                    fragment_part
-                )
+                fragment_name, fragment_extras = _strip_extras(fragment_part)
                 name = name if name else fragment_name
                 if fragment_extras:
                     parsed_extras = parsed_extras + tuple(parse_extras(fragment_extras))
                 name_with_extras = "{0}{1}".format(name, extras_to_string(parsed_extras))
-                parsed_dict["fragment"] = "egg={0}".format(name_with_extras)
         elif (
             parsed_dict.get("path") is not None and "&subdirectory" in parsed_dict["path"]
         ):
